use strict;
use Test::More tests => 1;

BEGIN {
    use_ok( 'ShipIt::Step::ChangePodVersion' );
}

diag( "Testing ShipIt::Step::ChangePodVersion $ShipIt::Step::ChangePodVersion::VERSION, Perl $], $^X" );
